@@ -484,10 +484,10 @@ async def generate(
     validate_output_path(output_path)
     for db_name, db_config_d in json.loads(open(config_path).read()).items():
         hydrate = db_config_d.get("hydrate", False)
-        # if hydrate is True, will include in second go
+        # must include strawberry types in both for circular dependency reasons
         s = await build_from_config(
             db_config_d=db_config_d,
-            include_strawberry=include_strawberry and not hydrate,
+            include_strawberry=include_strawberry,
         )
         open(output_path / f"{db_name}.py", "w").write(s)
         if hydrate:
